@@ -1,39 +1,39 @@
 package HTML::FormFu::Constraint::CallbackOnce;
 
-use strict;
-use warnings;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-use Scalar::Util qw/ blessed /;
-
-__PACKAGE__->mk_accessors(qw/ callback /);
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub process {
     my ( $self, $params ) = @_;
 
-    my $name = $self->name;
+    # check when condition
+    return if !$self->_process_when($params);
 
-    my $value = $params->{$name};
+    my $value = $self->get_nested_hash_value( $params, $self->nested_name );
 
     my $callback = $self->callback || sub {1};
-    
-    my $ok = eval {
-        $callback->( $value, $params );
-        };
 
-    return $self->mk_errors({
-        pass    => ( $@ or !$ok ) ? 0 : 1,
-        message => $@,
-    });
+    no strict 'refs';
+
+    my $ok = eval { $callback->( $value, $params ) };
+
+    return $self->mk_errors( {
+            pass => ( $@ or !$ok ) ? 0 : 1,
+            message => $@,
+        } );
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Constraint::CallbackOnce
+HTML::FormFu::Constraint::CallbackOnce - Code Callback Constraint
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ Arguments: \&sub_ref
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -81,3 +81,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
