@@ -1,33 +1,22 @@
 package HTML::FormFu::Deflator;
+use Moose;
 
-use strict;
-use warnings;
-use base 'Class::Accessor::Chained::Fast';
+with 'HTML::FormFu::Role::Populate';
 
-use HTML::FormFu::ObjectUtil qw( populate form name );
+use HTML::FormFu::Attribute qw( mk_inherited_accessors );
+use HTML::FormFu::ObjectUtil qw( form name parent );
 use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw/ parent type /);
+has type => ( is => 'rw', traits  => ['Chained'] );
 
-sub new {
-    my $class = shift;
-
-    my %attrs;
-    eval { %attrs = %{ $_[0] } if @_ };
-    croak "attributes argument must be a hashref" if $@;
-
-    my $self = bless {}, $class;
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+__PACKAGE__->mk_inherited_accessors(qw( locale ));
 
+sub BUILD {}
 sub process {
     my ( $self, $values ) = @_;
 
     if ( ref $values eq 'ARRAY' ) {
-        return [ map { $self->deflator($_); } @$values ];
+        return [ map { $self->deflator($_) } @$values ];
     }
     else {
         return $self->deflator($values);
@@ -35,20 +24,22 @@ sub process {
 }
 
 sub clone {
-    my ( $self ) = @_;
-    
+    my ($self) = @_;
+
     my %new = %$self;
-    
+
     return bless \%new, ref $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =head1 NAME
 
-HTML::FormFu::Filter - Deflator Base Class
+HTML::FormFu::Deflator - Deflator Base Class
 
 =head1 SYNOPSIS
 
@@ -72,6 +63,22 @@ Contains names of params to deflator.
 
 Arguments: $form_result, \%params
 
+=head1 CORE DEFLATORS
+
+=over
+
+=item L<HTML::FormFu::Deflator::CompoundDateTime>
+
+=item L<HTML::FormFu::Deflator::CompoundSplit>
+
+=item L<HTML::FormFu::Deflator::FormatNumber>
+
+=item L<HTML::FormFu::Deflator::PathClassFile>
+
+=item L<HTML::FormFu::Deflator::Strftime>
+
+=back
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
@@ -80,3 +87,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
